# 微博相册下载小工具

## 使用说明

```python
    安装: pip install weibo-photos
    查询相册列表: weibo-photos albums 用户id
    下载相册: weibo-photos photos 用户id 专辑id 专辑类型 --path 保存路径
    导出相册链接: weibo-photos export 用户id 专辑id 专辑类型
```

* 下载cURL的命令行工具，并设置到环境变量中
* 使用命令行操作，可以使用--help命令查看各选项

![image](https://wx2.sinaimg.cn/mw690/878a37e0gy1fz3yijnh9ej21hi1tie81.jpg)